@@ -16,7 +16,8 @@ class Backup(MainAttributes):
     dump_migration_files = models.IntegerField("Dump Migration Files", null=True, blank=True)
     created_at = models.DateTimeField()
     consistent_migrations = models.BooleanField("Consistent Migrations", default=False)
-
+    django_backup_utils_version = models.CharField("django-backup-utils version", max_length=10, null=True, blank=True)
+    backup_directories = models.TextField(null=True, blank=True)
     # inconsistent migrations occur if your migration recorder does not match your local migration files
 
     def __str__(self):
